@@ -34,8 +34,9 @@ def generate_help_message(names: [str], description: str, args: List[Argument])
     """
     synopsis = generate_synopsis(names, args)
 
-    flags = sorted(filter(lambda x: x.flag, args))
-    arguments = sorted(filter(lambda x: not x.flag, args))
+    flags = list(filter(lambda x: x.flag, args))
+    flags = sorted(flags, key=lambda x: x.name)
+    arguments = list(filter(lambda x: not x.flag, args))
 
     flags_description = generate_arguments_description(flags)
     arguments_description = generate_arguments_description(arguments)
@@ -89,8 +90,7 @@ def generate_arguments_description(args: List[Argument]) -> str:
     :param args: arguments
     :return: description
     """
-    sorted_args = sorted(args, key=lambda x: (x.optional, x.name))
-    argument_lines = list(map(generate_argument_description, sorted_args))
+    argument_lines = list(map(generate_argument_description, args))
     return "\n".join(argument_lines)
 
 
@@ -122,6 +122,6 @@ def generate_command_example(names: List[str], arguments: List[Argument], flags:
     :return: example call
     """
     arg_prefix = next(iter(ARG_NAMING_PREFIXES))
-    argument_examples = list(map(lambda x: "`{}`".format(x.example), arguments))
-    flag_examples = list(map(lambda x: "`{}{}`".format(arg_prefix, x.name), flags))
-    return "/{} {}".format(names[0], " ".join(argument_examples + flag_examples)).strip()
+    argument_examples = list(map(lambda x: "{}".format(x.example), arguments))
+    flag_examples = list(map(lambda x: "{}{}".format(arg_prefix, x.name), flags))
+    return "`/{} {}`".format(names[0], " ".join(argument_examples + flag_examples)).strip()
